@@ -3,8 +3,8 @@ mod default;
 use std::fmt::Display;
 
 pub use default::DefaultExecutor;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::bigint::{BigInt, Sign};
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::message::Message;
 use fvm_shared::receipt::Receipt;
